@@ -175,7 +175,7 @@ esym=[  "H" , "He", "Li", "Be", "B" , "C" , "N" , "O" , "F" , "Ne", "Na",
         "Rh", "Pd", "Ag", "Cd", "In", "Sn", "Sb", "Te", "I" , "Xe", "Cs",
         "Ba", "La", "Ce", "Pr", "Nd", "Pm", "Sm", "Eu", "Gd", "Tb", "Dy",
         "Ho", "Er", "Tm", "Yb", "Lu", "Hf", "Ta", "W" , "Re", "Os", "Ir",
-        "Pt", "Au", "Hd", "Tl", "Pb", "Bi", "Po", "At", "Rn", "Fr", "Ra",
+        "Pt", "Au", "Hg", "Tl", "Pb", "Bi", "Po", "At", "Rn", "Fr", "Ra",
         "Ac", "Th", "Pa", "U" , "Np", "Pu", "Am", "Cm", "Bk", "Cf", "Es",
         "Fm", "Md", "No", "Lw"]
 #K-edges (keV)
@@ -191,7 +191,7 @@ kedge={ 1: 0.140000E-01,   2: 0.250000E-01,   3: 0.550000E-01,
     28: 0.833300E+01,  29: 0.897900E+01,  30: 0.965900E+01,
     31: 0.103670E+02,  32: 0.111040E+02,  33: 0.118680E+02,
     34: 0.126580E+02,  35: 0.134740E+02,  36: 0.143220E+02,
-    37: 0.152000E+02,  38: 0.161050E+02,  39: 0.170800E+02,
+    37: 0.152000E+02,  38: 0.161050E+02,  39: 0.170380E+02,
     40: 0.179980E+02,  41: 0.189860E+02,  42: 0.199990E+02,
     43: 0.210450E+02,  44: 0.221170E+02,  45: 0.232200E+02,
     46: 0.243500E+02,  47: 0.255140E+02,  48: 0.267110E+02,
